'use strict';

var node_path = require('node:path');
var swaggerJsdoc = require('swagger-jsdoc');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var swaggerJsdoc__default = /*#__PURE__*/_interopDefaultLegacy(swaggerJsdoc);

const defaultOptions = {
  apiFolder: "pages/api",
  schemaFolders: [],
  definition: {
    openapi: "3.0.0",
    info: {
      title: "Next Swagger Doc Demo Api",
      version: "1.0"
    }
  }
};
const FILE_TYPES = ["ts", "tsx", "jsx", "js", "json", "swagger.yaml"];
function createSwaggerSpec({
  apiFolder = "pages/api",
  schemaFolders = [],
  ...swaggerOptions
} = defaultOptions) {
  const scanFolders = [apiFolder, ...schemaFolders];
  const apis = scanFolders.flatMap((folder) => {
    const buildApiDirectory = node_path.join(process.cwd(), ".next/server", folder);
    const apiDirectory = node_path.join(process.cwd(), folder);
    const publicDirectory = node_path.join(process.cwd(), "public");
    return [
      ...FILE_TYPES.map((fileType) => `${apiDirectory}/**/*.${fileType}`),
      // Only scan build directory for *.swagger.yaml and *.js files
      ...["js", "swagger.yaml", "json"].map(
        (fileType) => `${buildApiDirectory}/**/*.${fileType}`
      ),
      // Support load static files from public directory
      ...["swagger.yaml", "json"].map(
        (fileType) => `${publicDirectory}/**/*.${fileType}`
      )
    ];
  });
  const options = {
    apis,
    // Files containing annotations as above
    ...swaggerOptions
  };
  return swaggerJsdoc__default["default"](options);
}
function withSwagger({
  apiFolder = "pages/api",
  schemaFolders = [],
  ...swaggerOptions
} = defaultOptions) {
  return () => (_req, res) => {
    try {
      const swaggerSpec = createSwaggerSpec({
        apiFolder,
        schemaFolders,
        ...swaggerOptions
      });
      res.status(200).send(swaggerSpec);
    } catch (error) {
      res.status(400).send(error);
    }
  };
}

exports.createSwaggerSpec = createSwaggerSpec;
exports.withSwagger = withSwagger;
